Administrator's Guide
=====================

If you are a system administrator running Ironic, this section contains
information that may help you understand how to operate and upgrade
the services.

.. toctree::
  :maxdepth: 3

  drivers
  features
  operation
  architecture

.. toctree::
  :hidden:

  deploy-steps
